@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: itf14.py - Last Update: 3/23/2023 Ver. 2.8.6 RC 1 - Author: cooldude2k $
+    $FileInfo: itf14.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -38,6 +38,7 @@ def create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, Fal
  hidesn = hideinfo[0];
  hidecd = hideinfo[1];
  hidetext = hideinfo[2];
+ threewidebar = True;
  imageoutlib = imageoutlib.lower();
  if(not pilsupport and imageoutlib=="pillow"):
   imageoutlib = "cairo";
@@ -123,7 +124,10 @@ def create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, Fal
   pil_addon_fix = 0;
   cairo_addon_fix = 0;
  upc_matches = re.findall("([0-9]{2})", upc);
- upc_size_add = (len(upc_matches) * 18) * barwidth;
+ if(threewidebar):
+  upc_size_add = (len(upc_matches) * 18) * barwidth;
+ else:
+  upc_size_add = (len(upc_matches) * 14) * barwidth;
  if(len(upc_matches)<=0):
   return False;
  if(pilsupport and imageoutlib=="pillow"):
@@ -209,9 +213,10 @@ def create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, Fal
     drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib); 
     LineStart += barwidth; 
     BarNum += 1;
-    drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib); 
-    LineStart += barwidth;
-    BarNum += 1;
+    if(threewidebar):
+     drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib); 
+     LineStart += barwidth;
+     BarNum += 1;
    if(left_barcolor[InnerUPCNum]==0):
     drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib); 
     LineStart += barwidth;
@@ -223,16 +228,20 @@ def create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, Fal
     drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib); 
     LineStart += barwidth; 
     BarNum += 1;
-    drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib); 
-    LineStart += barwidth;
-    BarNum += 1;
+    if(threewidebar):
+     drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib); 
+     LineStart += barwidth;
+     BarNum += 1;
    if(right_barcolor[InnerUPCNum]==0):
     drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib);
     LineStart += barwidth;
     BarNum += 1;
    InnerUPCNum += 1;
   NumZero += 1;
- end_barcolor = [1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
+ if(threewidebar):
+  end_barcolor = [1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
+ else:
+  end_barcolor = [1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
  end_bc_num = 0;
  end_bc_num_end = len(end_barcolor);
  while(end_bc_num < end_bc_num_end):
@@ -276,12 +285,20 @@ def create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, Fal
  if(not hidetext):
   NumTxtZero = 0; 
   LineTxtStart = 23;
+  if(not threewidebar):
+   LineTxtStart -= 2;
   while (NumTxtZero < len(upc_matches)):
    ArrayDigit = list(upc_matches[NumTxtZero]);
    drawColorText(upc_img, 10 * int(resize), (LineTxtStart + (24 * (int(resize) - 1))) * barwidth, (barheight[0] + (4 * (int(resize))) + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), ArrayDigit[0], barcolor[1], "ocrb", imageoutlib);
-   LineTxtStart += 9 * int(resize);
+   if(threewidebar):
+    LineTxtStart += 9 * int(resize);
+   else:
+    LineTxtStart += 7 * int(resize);
    drawColorText(upc_img, 10 * int(resize), (LineTxtStart + (24 * (int(resize) - 1))) * barwidth, (barheight[0] + (4 * (int(resize))) + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), ArrayDigit[1], barcolor[1], "ocrb", imageoutlib);
-   LineTxtStart += 9 * int(resize);
+   if(threewidebar):
+    LineTxtStart += 9 * int(resize);
+   else:
+    LineTxtStart += 7 * int(resize);
    NumTxtZero += 1;
  del(upc_img);
  if(oldoutfile is None or isinstance(oldoutfile, bool)):
