@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: upce.py - Last Update: 3/23/2023 Ver. 2.8.6 RC 1 - Author: cooldude2k $
+    $FileInfo: upce.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -40,6 +40,11 @@ def create_upce_barcode(upc,outfile="./upce.png",resize=1,hideinfo=(False, False
  hidecd = hideinfo[1];
  hidetext = hideinfo[2];
  imageoutlib = imageoutlib.lower();
+ barheightadd = barheight[1];
+ if(barheight[0] > barheight[1]):
+  barheightadd = barheight[0] + 6;
+ else:
+  barheightadd = barheight[1];
  if(not pilsupport and imageoutlib=="pillow"):
   imageoutlib = "cairo";
  if(not cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
@@ -149,17 +154,17 @@ def create_upce_barcode(upc,outfile="./upce.png",resize=1,hideinfo=(False, False
  if(supplement is not None and len(supplement)==5): 
   addonsize = 56 * barwidth;
  if(pilsupport and imageoutlib=="pillow"):
-  upc_preimg = Image.new("RGB", ((69 * barwidth) + addonsize, barheight[1] + 9));
+  upc_preimg = Image.new("RGB", ((69 * barwidth) + addonsize, barheightadd + 9));
   upc_img = ImageDraw.Draw(upc_preimg);
-  upc_img.rectangle([(0, 0), ((69 * barwidth) + addonsize, barheight[1] + 9)], fill=barcolor[2]);
+  upc_img.rectangle([(0, 0), ((69 * barwidth) + addonsize, barheightadd + 9)], fill=barcolor[2]);
  if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   if(outfileext=="SVG"):
-   upc_preimg = cairo.SVGSurface(None, (69 * barwidth) + addonsize, barheight[1] + 9);
+   upc_preimg = cairo.SVGSurface(None, (69 * barwidth) + addonsize, barheightadd + 9);
   else:
-   upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (69 * barwidth) + addonsize, barheight[1] + 9);
+   upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (69 * barwidth) + addonsize, barheightadd + 9);
   upc_img = cairo.Context (upc_preimg);
   upc_img.set_antialias(cairo.ANTIALIAS_NONE);
-  upc_img.rectangle(0, 0, (69 * barwidth) + addonsize, barheight[1] + 9);
+  upc_img.rectangle(0, 0, (69 * barwidth) + addonsize, barheightadd + 9);
   upc_img.set_source_rgb(barcolor[2][0], barcolor[2][1], barcolor[2][2]);
   upc_img.fill();
  upc_array = { 'upc': upc, 'code': [ ] };
@@ -396,7 +401,7 @@ def create_upce_barcode(upc,outfile="./upce.png",resize=1,hideinfo=(False, False
   LineStart += barwidth;
   BarNum += 1;
  if(pilsupport and imageoutlib=="pillow"):
-  new_upc_img = upc_preimg.resize((((69 * barwidth) + addonsize) * int(resize), (barheight[1] + 9) * int(resize)), Image.NEAREST);
+  new_upc_img = upc_preimg.resize((((69 * barwidth) + addonsize) * int(resize), (barheightadd + 9) * int(resize)), Image.NEAREST);
   del(upc_img);
   del(upc_preimg);
   upc_img = ImageDraw.Draw(new_upc_img);
@@ -414,9 +419,9 @@ def create_upce_barcode(upc,outfile="./upce.png",resize=1,hideinfo=(False, False
      svgoutfile = StringIO();
     if(sys.version[0]>="3"):
      svgoutfile = BytesIO();
-   new_upc_preimg = cairo.SVGSurface(svgoutfile, ((69 * barwidth) + addonsize) * int(resize), (barheight[1] + 9) * int(resize));
+   new_upc_preimg = cairo.SVGSurface(svgoutfile, ((69 * barwidth) + addonsize) * int(resize), (barheightadd + 9) * int(resize));
   else:
-   new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((69 * barwidth) + addonsize) * int(resize), (barheight[1] + 9) * int(resize));
+   new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((69 * barwidth) + addonsize) * int(resize), (barheightadd + 9) * int(resize));
   new_upc_img = cairo.Context(new_upc_preimg);
   new_upc_img.set_source(upc_imgpat);
   new_upc_img.paint();
