@@ -11,11 +11,15 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: files.py - Last Update: 3/23/2023 Ver. 2.8.6 RC 1 - Author: cooldude2k $
+    $FileInfo: files.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
-import sys, re, json, platform, upcean.validate, upcean.support;
+import sys, re, platform, upcean.validate, upcean.support;
+try:
+ import simplejson as json;
+except ImportError:
+ import json;
 try:
  import xml.etree.cElementTree as cElementTree;
 except ImportError:
